



winpty-agent --version
IF %ERRORLEVEL% NEQ 0 exit 1
IF NOT EXIST %LIBRARY_INC%\winpty.h exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
IF NOT EXIST %LIBRARY_INC%\winpty_constants.h exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
IF NOT EXIST %LIBRARY_LIB%\winpty.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
IF NOT EXIST %LIBRARY_BIN%\winpty.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
exit 0
